from django.urls import path, re_path
from django.conf.urls import url 


from .views import user_views, requirements_views, main_req_views, suffix_req_views

urlpatterns = [
    path('users/', user_views.UserList.as_view(), name='api-user-list'),
    path('users/<uuid:pk>/', user_views.UserDetail.as_view(), name='api-post-details'),
    path('groupboilerplates/', requirements_views.BoilerplateGroupCreateAPIView.as_view(), name='api-groupboilerplates-create'),
    path('groupboilerplates/<int:pk>/', requirements_views.BoilerplateGroupDetailsAPIView.as_view(), name='api-groupboilerplates-list'),

    path('groupboilerplates/<int:groupboil>/boilerplates/', requirements_views.BoilerplateListCreateAPIView.as_view(), name='api-requirements-list'),
    path('groupboilerplates/<int:groupboil>/boilerplates/<int:pk>/', requirements_views.BoilerplateDetailsAPIView.as_view(), name='api-requirements-details'),
    path('groupboilerplates/<int:groupboil>/boilerplates/boilerplatedata/', requirements_views.BoilerplateDataListAPIView.as_view(), name='api-boilerlplate-list-data'),
    re_path('groupboilerplates/<int:groupboil>/boilerplates/(?:title=(?P<title_1>\w+)/)?$', requirements_views.BoilerplateList.as_view(), name='api-requirements-details-per-title'), 
    
    #'''Prefix'''
    path('groupboilerplates/<int:groupboil>/boilerplates/<int:boilerplate>/prefix/', requirements_views.PrefixListAPIView.as_view(), name='api-prefix-list'),
    path('groupboilerplates/<int:groupboil>/boilerplates/<int:boilerplate>/prefix/<int:pk>/', requirements_views.PrefixDetailsAPIView.as_view(), name='api-prefix-details'),

    #'''MAIN'''
    path('groupboilerplates/<int:groupboil>/boilerplates/<int:boilerplate>/main/', main_req_views.MainListAPIView.as_view(), name='api-main-list'),
    path('groupboilerplates/<int:groupboil>/boilerplates/<int:boilerplate>/main/<int:pk>/', main_req_views.MainDetailsAPIView.as_view(), name='api-main-details'),
    #'''SUFFIX'''
    path('groupboilerplates/<int:groupboil>/boilerplates/<int:boilerplate>/suffix/', suffix_req_views.SuffixListAPIView.as_view(), name='api-suffix-list'),
    path('groupboilerplates/<int:groupboil>/boilerplates/<int:boilerplate>/suffix/<int:pk>/', suffix_req_views.SuffixDetailsAPIView.as_view(), name='api-suffix-details'),

    #PREFIX CHOICES DATA
    path('prefix/choices/simpleprefix/', requirements_views.PrefixChoicesViewSet.as_view(), name='simpleprefixchoices'),
    path('prefix/choices/logicalconnectivity/', requirements_views.LogConChoicesViewSet.as_view(), name='logicalconnectivitychoices'),
    path('prefix/choices/verbprefix/', requirements_views.VerbChoicesViewSet.as_view(), name='verbprefixchoices'),
    path('prefix/choices/sysfunitem/', requirements_views.FunItemSysChoicesViewSet.as_view(), name='sysfunitem'),
    path('prefix/choices/staflowfunitem/', requirements_views.StaFlowFunItemChoicesViewSet.as_view(), name='staflowfunitem'),

    #MAIN CHOICES DATA
    path('main/choices/subject/', main_req_views.SysFunIntChoicesViewSet.as_view(), name='mainsubject'),
    path('main/choices/stateitem/', main_req_views.StatItemChoicesViewSet.as_view(), name='mainstateitem'),
    path('main/choices/statevalue/', main_req_views.StatevalueChoicesViewSet.as_view(), name='mainstatevalue'),
    path('main/choices/shall/', main_req_views.ShallChoicesViewSet.as_view(), name='mainshall'),
    path('main/choices/verb/', main_req_views.VerbChoicesViewSet.as_view(), name='mainverb'),
    path('main/choices/quantifier/', main_req_views.QuantChoicesViewSet.as_view(), name='mainquantifier'),
    path('main/choices/numunit/', main_req_views.NumUnitChoicesViewSet.as_view(), name='mainnumunit'),
    path('main/choices/fifuintsysstatset/', main_req_views.FlFuIntItSysStatSetChoicesViewSet.as_view(), name='mainfifuintsysstatset'),
    path('main/choices/stsysconset/', main_req_views.StaSysConSetChoicesViewSet.as_view(), name='mainstsysconset'),

    #SUFFIX CHOICES DATA
    path('suffix/choices/suffix/', suffix_req_views.SuffixChoicesViewSet.as_view(), name='suffixsuffix'),
    path('suffix/choices/numunits/', suffix_req_views.NumChoicesViewSet.as_view(), name='suffixnum'),
    path('suffix/choices/flow/', suffix_req_views.FlowChoicesViewSet.as_view(), name='suffixflow'),


]